@@ -67,7 +67,7 @@ class SpendController(BaseController):
                 user_id, user = user_row
                 val = 0
                 if user.resident:
-                    val = Decimal(100) / Decimal(num_residents)
+                    val = Decimal(1)
                 c.values['shares-%d.amount' % ii] = val
         else:
             c.title = 'Edit an Expenditure'
@@ -83,9 +83,7 @@ class SpendController(BaseController):
                 if c.expenditure.amount == 0:
                     percent = 0
                 else:
-                    percent = (Decimal(100) * Decimal(int(share)) /
-                               Decimal(int(c.expenditure.amount))).\
-                            quantize(Decimal("0.001"))
+                    percent = Decimal(int(share)) / Decimal(100)
                 c.values['shares-%d.amount' % ii] = percent
 
         return render('/spend/index.mako')
@@ -96,6 +94,8 @@ class SpendController(BaseController):
     def update(self, id=None):
         # Either create a new object, or, if we're editing, get the
         # old one
+        involved_users = set()
+
         if id is None:
             e = model.Expenditure()
             meta.Session.add(e)
@@ -104,6 +104,10 @@ class SpendController(BaseController):
             e = meta.Session.query(model.Expenditure).get(id)
             if e is None:
                 abort(404)
+            # If a user gets removed from a transaction, they should
+            # still get an email
+            involved_users.update(sp.user for sp in e.splits if sp.share != 0)
+            involved_users.add(e.spender)
             op = 'updated'
         
         # Set the fields that were submitted
@@ -124,7 +128,7 @@ class SpendController(BaseController):
         h.flash(show)
 
         # Send email notification to involved users if they have an email set.
-        involved_users = set(sp.user for sp in e.splits if sp.share != 0)
+        involved_users.update(sp.user for sp in e.splits if sp.share != 0)
         involved_users.add(e.spender)
         body = render('/emails/expenditure.txt',
                       extra_vars={'expenditure': e,
